OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Download" : "Last ned",
    "Copy link" : "Kopier lenke",
    "Click to copy the link to your clipboard" : "Klikk for å kopiere nettadressen til din utklippstavle",
    "Toggle sharing" : "Veksle deling",
    "Delete" : "Slett",
    "Rename" : "Gi nytt navn",
    "Share with users or groups" : "Del med brukere eller grupper",
    "can edit" : "kan redigere",
    "Close" : "Lukk",
    "Enabled" : "Aktiver",
    "Disabled" : "Deaktiver",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere",
    "Address book name" : "Navn på adressebok",
    "Only these special characters are allowed: -_.!?#|()" : "Kun disse spesialtegnene er tillatt: -_.!?#|()",
    "Address book could not be created." : "Kunne ikke opprette adressebok.",
    "The selected image is too big (max 1MB)" : "Det valgte bildet er for stort (maks 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Dette kortet var ødelagt, men er nå fikset. Sjekk at datene og hendelsen stemmer for å gjøre endringene permanente.",
    "No contacts in here" : "Ingen kontakter her",
    "Name" : "Navn",
    "Organization" : "Organisasjon",
    "Title" : "Tittel",
    "Add field …" : "Legg til felt…",
    "Save changes" : "Lagre endringer",
    "Address book" : "Adressebok",
    "Loading contacts …" : "Laster inn kontakter…",
    "Import into" : "Importer inn i",
    "Importing..." : "Importerer…",
    "Select your addressbook" : "Velg din adressebok",
    "Import is disabled because no writable address book had been found." : "Import er deaktivert siden det ikke finnes noe adressebøker som er skrivbare",
    "No search result for {query}" : "Intet søkeresultat for {query}",
    "All contacts" : "Alle kontakter",
    "Post office box" : "Postboks",
    "Postal code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller fylke",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(ny gruppe)",
    "Last name" : "Etternavn",
    "First name" : "Fornavn",
    "Additional names" : "Ev. mellomnavn",
    "Prefix" : "Prefiks",
    "Suffix" : "Suffiks",
    "Importing into" : "Importerer til",
    "New contact" : "Ny kontakt",
    "Not grouped" : "Ikke gruppert",
    "Sort by" : "Sorter etter",
    "There is no address book available to create a contact." : "Det finnes ingen adressebok å legge til kontakt i.",
    "{addressbook} shared by {owner}" : "{addressbook} delt av {owner}",
    "Contact not found." : "Fant ikke kontakten.",
    "You don't have permission to write to this addressbook." : "Du har ikke skrivetilgang til denne adresseboka.",
    "Contact could not be created." : "Kontakten kunne ikke opprettes",
    "No contacts in file. Only vCard files are allowed." : "Ingen kontakter i filen. Kun vCard filer er tillatt.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Kun vCard versjon 4.0 (RFC6350) eller versjon 3.0 (RFC2426) er støttet.",
    "Contact could not be moved." : "Kontakten kunne ikke flyttes.",
    "Contact could not be saved." : "Kontakten kunne ikke lagres.",
    "Waiting for the server to be ready…" : "Venter på at tjeneres skal bli klar…",
    "Importing…" : "Importerer…",
    "Display name" : "Visningsnavn",
    "Nickname" : "Kallenavn",
    "Detailed name" : "Detaljert navn",
    "Notes" : "Notater",
    "Website" : "Nettsted",
    "Federated Cloud ID" : "ID for sammenknyttet sky",
    "Home" : "Hjem",
    "Work" : "Jobb",
    "Other" : "Annet",
    "Groups" : "Grupper",
    "Birthday" : "Bursdag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Dødsdato",
    "Email" : "E-post",
    "Instant messaging" : "Direktemeldinger",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbeidstelefon",
    "Fax" : "Faks",
    "Fax home" : "Faks hjemme",
    "Fax work" : "Faks jobb",
    "Pager" : "Pager",
    "Voice" : "Svarer",
    "Car" : "Bil",
    "Work pager" : "Arbeidspersonsøker",
    "Social network" : "Sosialt nettverk",
    "Relationship" : "Forhold",
    "Spouse" : "Ektefelle",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Forelder",
    "Brother" : "Bror",
    "Sister" : "Søster",
    "Relative" : "Slektning",
    "Friend" : "Venn",
    "Colleague" : "Kollega",
    "Manager" : "Sjef",
    "Assistant" : "Assistent",
    "Gender" : "Kjønn",
    "Female" : "Mann",
    "Male" : "Dame",
    "Details" : "Detaljer",
    "Settings" : "Innstillinger"
},
"nplurals=2; plural=(n != 1);");
